PRO L1C_CLDIDX, SPEC, WNORES, BAND_VAL, CLDIDX
;
; VERSION
;   30OCT07  AD  Fix bug: remove 1pt offset in calculating cloud index
;   28JUL06  AD  Fix bug: calculate mean of whole MW not just end points
;   01NOV04  AD  Original. Based on parts of lv2pp.pro
;
; DESCRIPTION
;   Evaluate U.Le cloud index from L1B spectra
;
; ARGUMENTS
;   REAL*4    SPEC(*)       I  Spectrum [0-2410cm-1]
;   REAL*8    WNORES        I  Spectral resolution [cm-1]
;   INTEGER*1 BAND_VAL(5)   I  Band Validity (0=OK)
;   REAL*4    CLDIDX        O  Cloud Index

IF BAND_VAL(0) EQ 0 THEN BEGIN         ; A-band cloud channels
  MW1    = [788.200D0, 796.250D0]
  MW2    = [832.300D0, 834.400D0]
ENDIF ELSE BEGIN
  IF BAND_VAL(4) EQ 0 THEN BEGIN       ; D-band cloud channels
    MW1 = [1929.000D0, 1935.000D0] 
    MW2 = [1973.000D0, 1983.000D0]
    PRINT, 'W-L1C_CLDIDX: A band corrupt, using D band for Cloud Index'
  ENDIF ELSE BEGIN
    PRINT, 'W-L1C_CLDIDX: A&D bands both corrupt, setting Cloud Index=0'
    CLDIDX = 0.0
    RETURN
  ENDELSE
ENDELSE

; I1 and I2 are each 2-element arrays giving upper and lower indices
; (30OCT07: originally I1,I2 had +1 added to each, incorrectly)
I1 = ROUND ( MW1 / WNORES ) 
I2 = ROUND ( MW2 / WNORES )

; Can occasionally get spectra set = 0 although band_val = 0
IF MEAN ( SPEC[I1[0]:I1[1]] ) EQ 0.0 THEN CLDIDX = 0.0 ELSE $
  CLDIDX = MEAN ( SPEC[I1[0]:I1[1]] ) / MEAN ( SPEC[I2[0]:I2[1]] )
; This is what the incorrect code did...
;IF MEAN ( SPEC[I1] ) EQ 0.0 THEN CLDIDX = 0.0 ELSE $
;  CLDIDX = MEAN ( SPEC[I1] ) / MEAN ( SPEC[I2] )

; Limit CLDIDX to range 0:999
CLDIDX = MEDIAN ( [ 0, CLDIDX, 999. ] ) 

END
