PRO L1C_INPMIC, FIRST_WAVENUM, LAST_WAVENUM, WNORES, BATCHMODE, $
                NMIC, CODMIC, BNDMIC, WN1MIC, WN2MIC, HT1MIC, HT2MIC
;
; VERSION 
;   02MAR07  AD  Add BATCHMODE argument
;   02DEC04  AD  Add WNORES argument and check MW wavenumber boundaries
;   02NOV04  AD  Original. Based on Lv2PP procedure readmw.pro
;
; DESCRIPTION
;   Procedure to extract list of microwindows and associated information from
;   *.lst file
;
; ARGUMENTS
;   REAL*8      FIRST_WAVENUM(5) I  Lower wavenumber boundary of each band
;   REAL*8      LAST_WAVENUM(5)  I  Upper wavenumber boundary of each band
;   REAL*8      WNORES           I  Wavenumber resolution [cm-1]
;   INTEGER*4   BATCHMODE        I  1=run in batch mode, 0=run interactively
;   INTEGER*2   NMIC         O  No.of microwindows in .lst file
;   INTEGER*2   BNDMIC(NMIC) O  No.of microwindows in .lst file
;   CHARACTER*8 CODMIC(NMIC) O  List of MW labels 
;   REAL*8      WN1MIC(NMIC) O  Lower wavenumber boundaries
;   REAL*8      WN2MIC(NMIC) O  Upper wavenumber boundaries
;   REAL*4      HT1MIC(NMIC) O  Lower tangent altitude boundaries
;   REAL*4      HT2MIC(NMIC) O  Upper tangent altitude boundaries

NMIC = 0

; Get list of Microwindows - use standard filename if running in batch mode

IF BATCHMODE THEN FILMIC = 'mwlist.lst' ELSE BEGIN
  PRINT, 'Microwindow list [<CR>=none]', FORMAT='($,A)'
  FILMIC = ''
  READ, FILMIC, FORMAT='(A)'
; If no filename is supplied the L1C program simply extracts sweep headers.
  IF FILMIC EQ '' THEN RETURN
ENDELSE

OPENR, LUNMIC, FILMIC, /GET_LUN
RECORD = '!'
W1 = 0.0D0
W2 = 0.0D0
H1 = 0.0
H2 = 0.0
WHILE NOT EOF ( LUNMIC ) DO BEGIN
  READF, LUNMIC, RECORD
  IF STRMID ( RECORD, 0, 1 ) NE '!' AND STRTRIM ( RECORD ) NE '' THEN BEGIN
    MWCODE = STRMID ( RECORD, 4, 8 )
    READS, STRMID ( RECORD, 13 ), W1, W2, H1, H2
    IBAND = 0
    WHILE W1 GE LAST_WAVENUM[IBAND] AND IBAND LE 3 DO IBAND = IBAND + 1
    IF W1 GE LAST_WAVENUM[IBAND] OR W2 LE FIRST_WAVENUM[IBAND] THEN BEGIN
      PRINT, 'F-L1C_INPMIC: Illegal Waveno.range for MW=', MWCODE
      STOP
    ENDIF
    IF ABS ( W1/WNORES - ROUND(W1/WNORES) ) GT 0.01 THEN BEGIN        
      PRINT, 'F-L1C_INPMIC: Lower Waveno.limit for MW=', MWCODE, $
             ' does not match L1B resolution=', WNORES
      STOP
    ENDIF
    IF ABS ( W2/WNORES - ROUND(W2/WNORES) ) GT 0.01 THEN BEGIN
      PRINT, 'F-L1C_INPMIC: Upper Waveno.limit for MW=', MWCODE, $
             ' does not match L1B resolution=', WNORES
      STOP
    ENDIF
    NMIC = NMIC + 1
    IF NMIC EQ 1 THEN BEGIN
      CODMIC = [ MWCODE ]
      BNDMIC = [ IBAND ]
      WN1MIC = [ W1 ]
      WN2MIC = [ W2 ]
      HT1MIC = [ H1 ]
      HT2MIC = [ H2 ]
    ENDIF ELSE BEGIN
      CODMIC = [ CODMIC, MWCODE]
      BNDMIC = [ BNDMIC, IBAND ]
      WN1MIC = [ WN1MIC, W1 ]
      WN2MIC = [ WN2MIC, W2 ]
      HT1MIC = [ HT1MIC, H1 ]
      HT2MIC = [ HT2MIC, H2 ]
    ENDELSE
  ENDIF
ENDWHILE
FREE_LUN, LUNMIC

END
