PRO L1C_INPSPH, LUNL1B, SPH_SIZE, TOT_SWEEPS, TOT_SCANS, NUM_SWEEPS_PER_SCAN, $
                NUM_POINTS_PER_BAND,  FIRST_WAVENUM,  LAST_WAVENUM, $
                NUM_NESR_PNTS, NESR_FIRST_WAVENUM, NESR_LAST_WAVENUM,  $
                SCAN_ADS_OFFSET,  MDS_OFFSET, MDS_SIZE   
;
; VERSION 
;   02NOV04  AD  Original. Based on part of Lv2PP.
;
; DESCRIPTION
;   Procedure to extract information from L1B Specific Product Header 
;
; ARGUMENTS
;   INTEGER*4 LUNL1B                 I  LUN for L1B file
;   INTEGER*4 SPH_SIZE               I  Length [bytes] of SPH 
;   INTEGER*4 TOT_SWEEPS             O  No. sweeps in file
;   INTEGER*4 TOT_SCANS              O  No. scans in file
;   INTEGER*4 NUM_SWEEPS_PER_SCAN    O  No. sweeps per scan
;   INTEGER*4 NUM_POINTS_PER_BAND(5) O  No. spectral data points per band
;   REAL*8    FIRST_WAVENUM(5)       O  Lower wavenumber boundary of each band
;   REAL*8    LAST_WAVENUM(5)        O  Upper wavenumber boundary of each band
;   INTEGER*4 NUM_NESR_PNTS          O  No. points for which NESR is tabulated
;   REAL*8    NESR_FIRST_WAVENUM     O  Lower wavenumber for NESR tabulation
;   REAL*8    NESR_LAST_WAVENUM      O  Upper wavenumber for NESR tabulation
;   INTEGER*4 SCAN_ADS_OFFSET        O  Offset [bytes] for 1st SCAN ADS
;   INTEGER*4 MDS_OFFSET             O  Offset [bytes] for 1st MDS record
;   INTEGER*4 MDS_SIZE               O  Length [bytes] of MDS records

; Specific Product Header - 6760 bytes read as a single string 
SPH = STRING ( REPLICATE ( 32B, SPH_SIZE ) )
READU, LUNL1B, SPH

; Find number of sweeps in file
J = STRPOS ( SPH, 'TOT_SWEEPS=' )
TOT_SWEEPS = 0L
READS, STRMID ( SPH, J+12, 5 ), TOT_SWEEPS

; Find number of limb scan sequences in file
J = STRPOS ( SPH, 'TOT_SCANS=' )
TOT_SCANS = 0L
READS, STRMID ( SPH, J+11, 5), TOT_SCANS

; Find number of sweeps per nominal elevation scan
; 17 = Number of sweeps required for a complete nominal scan
J = STRPOS ( SPH, 'NUM_SWEEPS_PER_SCAN=' )
NUM_SWEEPS_PER_SCAN = 0L
READS, STRMID ( SPH, J+21, 5), NUM_SWEEPS_PER_SCAN

; Find number of points per band (assume 5 bands is fixed)
J = STRPOS ( SPH, 'NUM_POINTS_PER_BAND=' )
NUM_POINTS_PER_BAND = LONARR(5)
READS, STRMID ( SPH, J+21, 55 ), FORMAT='(5I11)', NUM_POINTS_PER_BAND

; Find lower wavenumber limits of each band
J = STRPOS ( SPH, 'FIRST_WAVENUM=' )
FIRST_WAVENUM = DBLARR(5)
READS, STRMID ( SPH, J+15, 125 ), FORMAT='(5D25.17)', FIRST_WAVENUM
J = STRPOS ( SPH, 'LAST_WAVENUM=' )
LAST_WAVENUM = DBLARR(5)
READS, STRMID ( SPH, J+14, 125 ), FORMAT='(5D25.17)', LAST_WAVENUM

; Find number of points used for tabulating NESR 
J = STRPOS ( SPH, 'NUM_NESR_PNTS=' )
NUM_NESR_PNTS = 0L
READS, STRMID ( SPH, J+15, 11), NUM_NESR_PNTS

; Find first frequency used for the NESR 
J = STRPOS ( SPH, 'NESR_FIRST_WAVENUM=' )
NESR_FIRST_WAVENUM = 0.0D0
READS, STRMID ( SPH, J+19, 25 ), NESR_FIRST_WAVENUM

; Find last frequency used for the NESR 
J = STRPOS ( SPH, 'NESR_LAST_WAVENUM=' )
NESR_LAST_WAVENUM = 0.0D0
READS, STRMID ( SPH, J+18, 25 ), NESR_LAST_WAVENUM

; Find position of the first Scan Information ADS
J = STRPOS ( SPH, 'SCAN INFORMATION ADS' )
SCAN_ADS_OFFSET = 0L
READS, STRMID ( SPH, J+125, 20 ), SCAN_ADS_OFFSET

; Find position of first MDS 
I = STRPOS ( SPH, 'MIPAS LEVEL-1B MDS' ) 
MDS_OFFSET = 0L
READS, STRMID ( SPH, I+125, 20 ) , MDS_OFFSET   

; Find length of each MDS record
MDS_SIZE = 0L
READS, STRMID ( SPH, I+219, 11 ), MDS_SIZE    ; 239441 for 0.025cm-1 resln

END
