PRO L1C_NBFAC, NSPC, RESFAC, NSPCZF, NBFAC
;
; VERSION
;   02DEC04  AD  Add RESFAC argument
;   02NOV04  AD  Original. Based on original Lv2PP module apod.pro
;
; DESCRIPTION
;   Calculate NB factor for apodisation of MIPAS spectra
;
; ARGUMENTS
;   INTEGER*4 NSPC          I No. of points in actual spec (element#0=0cm-1)
;   REAL*8    RESFAC        I Factor for reduction in spectral resolution
;   INTEGER*4 NSPCZF        O No. of points in zero-filled spectrum
;   REAL*4    NBFAC(NSPCZF) O Norton-Beer apodisation factors

; Round up to next power of 2 for FFT
I = 16
WHILE NSPC GT 2L^I DO I = I + 1

IF RESFAC NE 1.0D0 THEN I=20
; If changing the resolution it is necessary to use a larger array for the FFT
; to avoid interpolation errors in the interferogram domain. Such errors 
; normally mean that the mean radiance of the interpolated spectra will be
; smaller than the mean radiance of the original spectra. Tests show that for
; different values i the maximum error (usually D-band) in mean radiance when
; converting 0.025cm-1 spectra to 0.0625cm-1 spectra is
; i=17 18%, i=18 9%, i=19 2.2%, i=20 0.5%, i=21 0.15% - see notes from 03DEC04

NSPCZF = 2L^I

NBFAC = FLTARR ( NSPCZF )

; Coefficients of the Norton-Beer STRONG
RC0 = 0.045335
RC2 = 0.554883
RC4 = 0.399782

DELTA = 1.D0 / DOUBLE ( NSPCZF*RESFAC )
DELTA2 = DELTA*DELTA

FOR I = 0L, NSPCZF*RESFAC-1 DO BEGIN       
  DU2 = 1.0D0 - DELTA2 * FLOAT ( I )^2
  DU4 = DU2 * DU2
  NBFAC[I] = ( RC0 + ( RC4*DU4 + RC2 ) * DU4 ) 
ENDFOR

END
