PRO L1C_WRTHDR, LUNL1C, VERSION, L1CFMT, L1BFIL, NUM_SWEEPS_PER_SCAN, RESL1C, $
                RESFAC
;
; VERSION 
;   23MAY05  AD  Add RESL1C argument
;   07DEC04  AD  Correct header to write "l1c.pro" instead of "LV2PP"
;   02DEC04  AD  Add RESFAC argument, and add to header if not equal to 1
;   02NOV04  AD  Original. Based on Lv2PP procedure readmw.pro
;
; DESCRIPTION
; Procedure to write header of L1C file.
;
; ARGUMENTS
;   INTEGER*4     LUNL1C          I  LUN for L1C file
;   CHARACTER*7   VERSION         I  Program version identifier
;   REAL*4        L1CFMT          I  L1C format version
;   CHARACTER*(*) L1BFIL          I  L1B directory + file name 
;   INTEGER*4 NUM_SWEEPS_PER_SCAN I  No. sweeps per scan
;   REAL*8        RESL1C          I  Resolution of output spectra
;   REAL*8        RESFAC          I  Resolution reduction factor

PRINTF, LUNL1C, '! L1C file generated by l1c.pro v.' + VERSION + ' on ' + $
  STRMID ( SYSTIME(0), 0, 20 )

L1BNAM = L1BFIL
; Remove any directory path from front of filename
ISLASH = STRPOS ( L1BFIL, '/', /REVERSE_SEARCH )
IF ISLASH GE 0 THEN L1BNAM = STRMID ( L1BFIL, ISLASH+1 )
 
PRINTF, LUNL1C, '! L1B FILE: ' + L1BNAM
IF RESFAC NE 1.0D0 THEN $
  PRINTF, LUNL1C, '! Original resolution reduced by factor=', RESFAC
PRINTF, LUNL1C, '! L1C FORMAT: http://www.atm.ox.ac.uk/group/mipas/L1C/'
PRINTF, LUNL1C,  L1CFMT, FORMAT='(F3.1)'
IF L1CFMT GE 2.0 THEN PRINTF, LUNL1C, 1, RESL1C, FORMAT='(I5,F10.4)'
PRINTF, LUNL1C,  NUM_SWEEPS_PER_SCAN, FORMAT='(I5)'

END
