PRO L1C_WRTSWP, LUNL1C, MDS_TIME, ABS_ORBIT, ISWP, ALT, ALT_NOM, LAT, LON, $
  RAD_EARTH, NMWSWP, CLDRAD, CLDIDX
;
; VERSION 
;   07DEC04  AD  Change name of argument ALT_ERR to ALT_NOM
;   28OCT04  AD  Original. Based on Lv2PP procedure readmw.pro
;
; DESCRIPTION
; Procedure to write header of L1C file.
;
; ARGUMENTS
;   INTEGER*4 LUNL1C         I  LUN for L1C file
;   INTEGER*4 MDS_TIME(3)    I  Time of sweep [Days,HHMMSS,.tttt]
;   INTEGER*4 ABS_ORBIT      I  Orbit Number
;   INTEGER*2 ISWP           I  Sweep# within scan, starting at 0
;   REAL*8    ALT            I  Tangent altitude [km]
;   REAL*8    ALT_NOM        I  Tangent altitude error [km]
;   REAL*4    LAT            I  Latitude [deg N]
;   REAL*4    LON            I  Longitude [deg]
;   REAL*8    RAD_EARTH      I  Earth Radius of Curvature [km]
;   INTEGER*2 NMWSWP         I  No.of microwindows 
;   REAL*4    CLDRAD         I  Cloud detection Channel Radiance
;   REAL*4    CLDIDX         I  Cloud Index

; Convert MDS_TIME to iyear (yyyy), iday (ddd), date (yyyymmdd), time (hhmmss)
    L1C_TIME, MDS_TIME, IYEAR, IDAY, ISEC, DATE, TIME

; Computation of Local Solar Time (LST) and Solar Zenith Angle (SZA)
    L1C_SZALST, IYEAR, IDAY, ISEC, LAT, LON, SZA, LST

; Print time/orbit identification 
PRINTF, LUNL1C, MDS_TIME[0], MDS_TIME[1], DATE, TIME, $
  ABS_ORBIT, LST, SZA, FORMAT='(I5,2X,I5,2X,a,2X,a,2X,I5,2(2X,F10.4))'

; Print location identification
PRINTF, LUNL1C, ISWP+1, ALT, ALT_NOM, LAT, LON, RAD_EARTH, NMWSWP, CLDRAD, $
  CLDIDX, FORMAT='(I5,2(X,D9.4),2(X,F9.4),X,D10.4,X,I3,X,f9.3,X,f7.3)'

END
